@@ -192,7 +192,7 @@ static void carp_send_ad(struct carp_softc *sc)
         advskew = CARP_BULK_UPDATE_MIN_DELAY;
     }    
     tv.tv_sec = advbase;
-    tv.tv_usec = advskew * 1000000 / 256;
+    tv.tv_usec = (unsigned int) (advskew * 1000000ULL / 256ULL);
 
     ch.carp_version = CARP_VERSION;
     ch.carp_type = CARP_ADVERTISEMENT;
@@ -313,7 +313,7 @@ static void carp_setrun(struct carp_softc *sc, sa_family_t af)
     case BACKUP:
         sc->sc_ad_tmo.tv_sec = 0;
         tv.tv_sec = (unsigned int) sc->sc_advbase * dead_ratio;
-        tv.tv_usec = sc->sc_advskew * 1000000U / 256U;
+        tv.tv_usec = (unsigned int) (sc->sc_advskew * 1000000ULL / 256ULL);
         switch (af) {        
         case AF_INET:
             sc->sc_md_tmo.tv_sec = now.tv_sec + tv.tv_sec;
@@ -339,7 +339,7 @@ static void carp_setrun(struct carp_softc *sc, sa_family_t af)
         break;
     case MASTER:
         tv.tv_sec = (unsigned int) sc->sc_advbase;
-        tv.tv_usec = sc->sc_advskew * 1000000U / 256U;
+        tv.tv_usec = (unsigned int) (sc->sc_advskew * 1000000ULL / 256ULL);
         sc->sc_md_tmo.tv_sec = now.tv_sec + tv.tv_sec;
         sc->sc_md_tmo.tv_usec = now.tv_usec + tv.tv_usec;
         /* No IPv6 scheduling ? */
@@ -507,15 +507,21 @@ static void packethandler(unsigned char *dummy,
         tmp_counter = ntohl(ch.carp_counter[0]);
         tmp_counter = tmp_counter << 32;
         tmp_counter += ntohl(ch.carp_counter[1]);
-        if (sc.sc_init_counter != 0) {
-            sc.sc_init_counter = 0;
-        }
+        sc.sc_init_counter = 0;
         sc.sc_counter = tmp_counter;
         
         sc_tv.tv_sec = (unsigned int) sc.sc_advbase;
-        sc_tv.tv_usec = sc.sc_advskew * 1000000U / 256U;
+        if (carp_suppress_preempt != 0 &&
+            sc.sc_advskew < CARP_BULK_UPDATE_MIN_DELAY) {
+            sc_tv.tv_usec = (unsigned int)
+                (CARP_BULK_UPDATE_MIN_DELAY * 1000000ULL / 256ULL);
+        } else {
+            sc_tv.tv_usec = (unsigned int)
+                (sc.sc_advskew * 1000000ULL / 256ULL);
+        }
         ch_tv.tv_sec = (unsigned int) ch.carp_advbase;
-        ch_tv.tv_usec = ch.carp_advskew * 1000000U / 256U;
+        ch_tv.tv_usec = (unsigned int)
+            (ch.carp_advskew * 1000000ULL / 256ULL);
         
 #ifdef DEBUG
         printf("sc_tv(local) = [%lu] ch_tv(remote) = [%lu]\n",
@@ -544,8 +550,7 @@ static void packethandler(unsigned char *dummy,
              * If we're pre-empting masters who advertise slower than us,
              * and this one claims to be slower, treat him as down.
              */
-            if (preempt != 0 && carp_suppress_preempt == 0 &&
-                timercmp(&sc_tv, &ch_tv, <)) {
+            if (preempt != 0 && timercmp(&sc_tv, &ch_tv, <)) {
                 carp_master_down(&sc);
                 puts("Putting MASTER down - preemption");                
                 break;
