@@ -33,6 +33,7 @@ static void usage(void)
          "--upscript=<file> (-u <file>) : run <file> to become a master\n"
          "--downscript=<file> (-d <file>) : run <file> to become a backup\n"
          "--deadratio=<ratio> (-r <ratio>) : ratio to consider a host as dead\n"
+         "--shutdown (-z) : call shutdown script at exit\n"         
          "\n"
          "Sample usage :\n"
          "\n"
@@ -137,6 +138,10 @@ int main(int argc, char *argv[])
             dead_ratio = (unsigned int) strtoul(optarg, NULL, 0);
             break;
         }
+        case 'z': {
+            shutdown_at_exit = 1;
+            break;
+        }
         default: {
             usage();
         }
