@@ -1,7 +1,7 @@
 #ifndef __CARP_P_H__
 #define __CARP_P_H__ 1
 
-static const char *GETOPT_OPTIONS = "i:s:v:p:Pa:hb:k:u:d:r:";
+static const char *GETOPT_OPTIONS = "i:s:v:p:Pa:hb:k:u:d:r:z";
 
 static struct option long_options[] = {
     { "interface", 1, NULL, 'i' },
@@ -16,6 +16,7 @@ static struct option long_options[] = {
     { "upscript", 1, NULL, 'u' },
     { "downscript", 1, NULL, 'd' },
     { "deadratio", 1, NULL, 'r' },
+    { "shutdown", 0, NULL, 'z' },    
     { NULL, 0, NULL, 0 }
 };
 
